@@ -16,6 +16,7 @@ from aryaxai.common.xai_uris import (
 )
 from aryaxai.core.project import Project
 from aryaxai.core.text import TextProject
+from aryaxai.core.agent import AgentProject
 
 
 class Workspace(BaseModel):
@@ -156,6 +157,7 @@ class Workspace(BaseModel):
             raise Exception("Project Not Found")
         
         if project.get("metadata",{}).get("modality") == "text": return TextProject(api_client=self.api_client, **project)
+        elif project.get("metadata",{}).get("modality") == "agent": return AgentProject(api_client=self.api_client, **project)
 
         return Project(api_client=self.api_client, **project)
 
@@ -202,12 +204,13 @@ class Workspace(BaseModel):
 
         if not res["success"]:
             raise Exception(res["details"])
-
-        if modality != "text":
-            project = Project(api_client=self.api_client, **res["details"])
-
+        
         if modality == "text":
             project = TextProject(api_client=self.api_client, **res["details"])
+        elif modality == "agent":
+            project = AgentProject(api_client=self.api_client, **res["details"])
+        else:
+            project = Project(api_client=self.api_client, **res["details"])
 
         return project
 
